import { Box, Container, CssBaseline } from '@mui/material';
import { AppToolBar } from './components/UI/AppToolbar';
import { Route, Routes, useNavigate } from 'react-router-dom';
import { Products } from './containers/Products';
import { NewProduct } from './containers/NewProduct';
import Auth from './containers/Auth';
import { ProtectedRoute } from './components/UI/ProtectedRoute';
import { useAppDispatch, useAppSelector } from './store/hooks';
import { shallowEqual } from 'react-redux';
import { useEffect } from 'react';
import { notification } from 'antd';
import './App.css';
import { refreshToken } from './features/usersSlice';

function App() {
  const dispatch = useAppDispatch();
  const navigate = useNavigate();
  const { user, error } = useAppSelector((state) => state.user, shallowEqual);

  useEffect(() => {
    if (user) {
      navigate('/');
    } else {
      dispatch(refreshToken());
    }
  }, [dispatch, user]);

  useEffect(() => {
    if (error) {
      notification.error({
        message: error as unknown as string,
      });
    }
  }, [error]);

  return (
    <>
      <CssBaseline />
      <header>
        <AppToolBar />
      </header>
      <main>
        <Container maxWidth="xl">
          <Box component="main" sx={{ mt: 10 }}>
            <Routes>
              <Route
                path="/"
                element={
                  <ProtectedRoute user={user}>
                    <Products />
                  </ProtectedRoute>
                }
              />
              <Route
                path="/products"
                element={
                  <ProtectedRoute user={user}>
                    <NewProduct />
                  </ProtectedRoute>
                }
              />
              <Route path="/auth" element={<Auth />} />
            </Routes>
          </Box>
        </Container>
      </main>
    </>
  );
}

export default App;
