import { Button, Col, Form, FormProps, Input, Switch } from 'antd';
import { LockOutlined, UserOutlined } from '@ant-design/icons';
import { useAppDispatch } from '../store/hooks';
import { login, register } from '../features/usersSlice';
import { useState } from 'react';

export type AuthFieldType = {
  username: string;
  password: string;
};

export function AuthForm() {
  const dispatch = useAppDispatch();

  const [isLogin, setIsLogin] = useState(true);

  const onFinish: FormProps<AuthFieldType>['onFinish'] = (values) => {
    dispatch(isLogin ? login(values) : register(values));
  };

  return (
    <Col>
      <Switch
        checkedChildren="Login"
        unCheckedChildren="Register"
        style={{ marginBottom: '25px' }}
        value={isLogin}
        onChange={(val) => setIsLogin(val)}
      />
      <Form
        name="registration-form"
        onFinish={onFinish}
        title="Login/Register"
        style={{ width: 800 }}
        labelCol={{ span: 4 }}
        wrapperCol={{ span: 16 }}
      >
        <Form.Item<AuthFieldType>
          name="username"
          label="User name"
          rules={[{ required: true, message: 'Please input your Username!' }]}
        >
          <Input prefix={<UserOutlined className="site-form-item-icon" />} placeholder="Username" />
        </Form.Item>

        <Form.Item<AuthFieldType>
          name="password"
          label="password"
          rules={[{ required: true, message: 'Please input your Password!' }]}
        >
          <Input
            prefix={<LockOutlined className="site-form-item-icon" />}
            type="password"
            placeholder="Password"
          />
        </Form.Item>

        <Form.Item label={null}>
          <Button type="primary" htmlType="submit">
            Submit
          </Button>
        </Form.Item>
      </Form>
    </Col>
  );
}
