import { ChangeEvent, FormEvent, useState } from 'react';
import { FileInput } from './UI/FileInput';
import { Box, Button, Grid, TextField } from '@mui/material';
import { useAppDispatch } from '..//store/hooks';
import { useNavigate } from 'react-router-dom';
import { createProduct } from '../features/productsSlice';

interface NewProductState {
  title: string;
  price: number;
  description?: string;
  image?: File;
}

export function ProductForm() {
  const dispatch = useAppDispatch();
  const navigate = useNavigate();
  const [product, setProduct] = useState<NewProductState>({
    price: 0,
    title: '',
  });

  const submitFormHandler = async (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();

    const formData = new FormData();
    Object.entries(product).forEach(([key, value]) => {
      if (typeof value === 'object') {
        formData.append(key, value);
      } else {
        formData.append(key, `${value}`);
      }
    });

    await dispatch(createProduct(formData));

    navigate('/');
  };

  const fileChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
    if (e?.target?.files?.[0]) {
      const file: File = e.target.files[0];
      setProduct((prevProduct) => {
        return { ...prevProduct, image: file };
      });
    }
  };

  const inputChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setProduct((prevState) => {
      return { ...prevState, [name]: value };
    });
  };

  return (
    <Box component={'form'} autoComplete="off" onSubmit={submitFormHandler} paddingY={2}>
      <Grid container direction="column" spacing={2}>
        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="title"
            label="Title"
            value={product.title}
            onChange={inputChangeHandler}
            name="title"
          />
        </Grid>
        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="price"
            label="Price"
            value={product.price}
            onChange={inputChangeHandler}
            name="price"
          />
        </Grid>
        <Grid item xs>
          <TextField
            fullWidth
            multiline
            rows={3}
            variant="outlined"
            id="description"
            label="Description"
            value={product.description}
            onChange={inputChangeHandler}
            name="description"
          />
        </Grid>
        <Grid item xs>
          <FileInput label="Image" name="image" onChange={fileChangeHandler} />
        </Grid>
        <Grid item xs>
          <Button type="submit" color="primary" variant="contained">
            Create
          </Button>
        </Grid>
      </Grid>
    </Box>
  );
}
