import {
  Card,
  CardActions,
  CardContent,
  CardHeader,
  CardMedia,
  Grid,
  IconButton,
  Typography,
} from '@mui/material';
import { IProduct } from '../containers/Products';
import { ArrowForward } from '@mui/icons-material';
import { Link } from 'react-router-dom';

interface Props {
  product: IProduct;
}

export const ProductItem = ({ product }: Props) => {
  const { title, description, price, id, image } = product;

  let cardImage = 'http://localhost:5173/image_not_available.png';
  if (image) {
    cardImage = `http://localhost:5000/uploads/${image}`;
  }

  return (
    <Grid item xs={12} sm={12} md={6} lg={4}>
      <Card>
        <CardHeader title={title} />
        <CardMedia image={cardImage} title={title} sx={{ height: 200 }} />
        <CardContent>
          <Typography variant="body2">{description}</Typography>
          <strong style={{ marginLeft: '10px' }}>Price: {price}$</strong>
        </CardContent>
        <CardActions>
          <IconButton component={Link} to={`/products/${id}`}>
            <ArrowForward />
          </IconButton>
        </CardActions>
      </Card>
    </Grid>
  );
};
