import { Button, Stack, styled, TextField } from '@mui/material';
import { ChangeEvent, useRef, useState } from 'react';

interface Props {
  name: string;
  label: string;
  onChange: (e: ChangeEvent<HTMLInputElement>) => void;
  // ChangeEventHandler<HTMLInputElement>
}

const HiddenInput = styled('input')({ display: 'none' });

export function FileInput({ name, label, onChange }: Props) {
  const inputRef = useRef<HTMLInputElement>(null);
  const [fileName, setFileName] = useState('');

  const activeInput = () => {
    if (inputRef.current) {
      inputRef.current.click();
    }
  };

  const onFileChange = (e: ChangeEvent<HTMLInputElement>) => {
    if (e?.target?.files?.[0]?.name) {
      setFileName(e.target.files[0].name);
    } else {
      setFileName('');
    }
    onChange(e);
  };

  return (
    <>
      <HiddenInput type="file" ref={inputRef} name={name} onChange={onFileChange} />
      <Stack direction="row" spacing={1} sx={{ mb: 1 }}>
        <TextField
          value={fileName}
          variant="outlined"
          label={label}
          onClick={activeInput}
          fullWidth
          disabled
        />
        <Button variant="contained" onClick={activeInput}>
          Browse
        </Button>
      </Stack>
    </>
  );
}
