/**
 * @description Декоратор для свойства: Автоматическое логирование изменений
 * @param target объект, к которому применяется декоратор
 * @param propertyKey имя свойства или метода
 */
function logProperty(target: any, propertyKey: string) {
  let value: string;
  console.log("propertyKey", propertyKey, JSON.stringify(target));
  
  const originalValue = target[propertyKey];

  const getter = () => value;
  const setter = (newValue: string) => {
    console.log(`Изменение свойства ${propertyKey}: от ${originalValue} к ${newValue}`);
    value = newValue;    
  }

  Object.defineProperty(target, propertyKey, {
    get: getter,
    set: setter,
    configurable: true,
    enumerable: true,
  })
}


class Person {
  @logProperty
  name!: string;

  @logProperty
  age!: number;
}
const person = new Person();
person.name = "Mary";
person.name = "John";
person.age = 12;