import { Injectable } from '@nestjs/common';
import { CreateCategoryDto } from './dto/create-category.dto';
import { InjectRepository } from '@nestjs/typeorm';
import { Category } from './entities/category.entity';
import { Repository } from 'typeorm';

@Injectable()
export class CategoryService {
  constructor(
    @InjectRepository(Category) private categoryRepo: Repository<Category>,
  ) {}

  async create(createCategoryDto: CreateCategoryDto): Promise<Category> {
    const category = this.categoryRepo.create(createCategoryDto);
    await this.categoryRepo.save(category);
    return category;
  }

  async findAll(): Promise<Category[]> {
    return await this.categoryRepo.find();
  }

  async findOne(id: number): Promise<Category | null> {
    return await this.categoryRepo.findOneBy({ id });
  }

  async clear() {
    try {
      const isEmpty = await this.categoryRepo.countBy({});
      if (isEmpty) {
        await this.categoryRepo.delete({});
      }
    } catch {
      throw new Error('Clear error');
    }
  }

  async remove(id: number): Promise<number> {
    await this.categoryRepo.delete({ id });
    return id;
  }
}
