import { Injectable } from '@nestjs/common';
import { CategoryService } from 'src/category/category.service';
import { ProductService } from 'src/product/product.service';
import { faker } from '@faker-js/faker';
import { Category } from 'src/category/entities/category.entity';
import { Product } from 'src/product/entities/product.entity';

@Injectable()
export class SeedService {
  constructor(
    private productService: ProductService,
    private categoryService: CategoryService,
  ) {}

  async create() {
    await this.categoryService.clear();
    await this.productService.clear();

    const categories: Category[] = [];
    const products: Product[] = [];

    for (let i = 0; i < 50; i++) {
      const name = faker.food.dish();
      const description = faker.food.description();
      const category = await this.categoryService.create({
        name,
        description,
      });
      categories.push(category);
    }

    for (let i = 0; i < categories.length; i++) {
      const title = faker.food.meat();
      const description = faker.food.description();
      const price = faker.number.int({ min: 100, max: 1000 });

      const product = await this.productService.create({
        title,
        description,
        price,
        categoryId: categories[i].id,
      });

      products.push(product);
    }

    return {
      products,
      categories,
    };
  }
}
